//--------------
// Replication files for "Does Foreign Aid Target the Poorest?" by Ryan Briggs
// ryancbriggs@vt.edu
//--------------
// This .do file requires the packages coefplot and outreg2 to be installed
// type: ssc install coefplot
// type: ssc install outreg2
//--------------

//load data (set to proper working directory if required)
use "RegionalAidReplicate.dta"

//set group variable for FE
xtset adm0_codey

//Kenya table (Table 1)
clist country region poorest_tot poorer_tot middle_tot richer_tot richest_tot if country=="Kenya"
clist country region unequal if country=="Kenya"

//Ghana table (in appednix)
clist country region poorest_tot poorer_tot middle_tot richer_tot richest_tot if country=="Ghana"

//Show correlations between income groups for all countries
//If you take the mean of each cell (over all countries) you will produce Table 2
by adm0_codey, sort : corr poorest_tot poorer_tot middle_tot richer_tot richest_tot 

//correlations between total numbers of projects and total cost of projects per regions
corr totalproj totalcost
scatter prop_totalcost prop_totalproj

//----MAIN REGRESSION TABLE----
//TABLE 3
xtreg prop_totalcost poorest_tot richest_tot capital prop_battles prop_area, robust fe
	outreg2 using MainTable.xls, se nolabel dec(2) coefastr ctitle(Cost) replace
xtreg prop_totalproj poorest_tot richest_tot capital prop_battles prop_area, robust fe
	outreg2 using  MainTable.xls, se nolabel dec(2) coefastr ctitle(Proj) append
xtreg logCost log_poorest log_richest capital acled_battles log_area, robust fe
	outreg2 using  MainTable.xls, se nolabel dec(2) coefastr ctitle(LogCost) append

//FIGURE 1
//total number of (sub) projects per country
graph hbar (mean) totprojpercountry, over(country)

//FIGURE 2 is simply a scatter plot of Census estimates for Ghana and Kenya and
//DHS-derived estimates from the dataset. I made the scatter plot by hand, using the data produced below
//and the program GraphSketcher: https://github.com/graphsketcher/GraphSketcher
//The DHS-derived esimates are produced using:
clist country region poorest_tot poorer_tot middle_tot richer_tot richest_tot if country=="Kenya"
clist country region poorest_tot poorer_tot middle_tot richer_tot richest_tot if country=="Ghana"

//FIGURE 3
//bivariate effects across wealth groupings
foreach var in poorest_tot poorer_tot middle_tot richer_tot richest_tot {
	quietly xtreg prop_totalcost `var', robust fe
		estimates store `var'1
	quietly xtreg prop_totalproj `var', robust fe
		estimates store `var'2
}
coefplot (poorest_tot1 \ poorer_tot1 \ middle_tot1 \ richer_tot1 \ richest_tot1, label("% of Value")) (poorest_tot2 \ poorer_tot2 \ middle_tot2 \ richer_tot2 \ richest_tot2, label("% of Projects")), drop(_cons) xline(0) title("Regional Shares")  msymbol(O) name(bivariate1, replace) nodraw

//bivariate effects across wealth groupings, with logged variables
foreach var in log_poorest log_poorer log_middle log_richer log_richest {
	quietly xtreg logCost `var', robust fe
		estimates store `var'1
}
coefplot (log_poorest1 \ log_poorer1 \ log_middle1 \ log_richer1 \ log_richest1, label("ln(Total Aid Value)")), drop(_cons) xline(0) msymbol(O) title("Logged Variables") name(bivariate2, replace) nodraw
graph combine bivariate1 bivariate2, cols(2)
	
	
//APPENDIX TABLES

//summary statistics for variables in regressions
sum prop_totalcost prop_totalproj logCost poorest_tot richest_tot log_poorest log_richest capital prop_battles acled_battles prop_area log_area

//Scatter plots of de-meaned DV and key IVs, with and without logs, bivariate results
//This graphically show how the log improves the fit, but that it doesn't change the overall pattern
egen logCost_mean = mean(logCost), by(adm0_codey)
egen poorest_tot_mean = mean(poorest_tot), by(adm0_codey)
egen log_poorest_mean = mean(log_poorest), by(adm0_codey)
egen richest_tot_mean = mean(richest_tot), by(adm0_codey)
egen log_richest_mean = mean(log_richest), by(adm0_codey)
gen logCost_diff = logCost - logCost_mean
gen poorest_tot_diff = poorest_tot -  poorest_tot_mean
gen log_poorest_diff = log_poorest - log_poorest_mean
gen richest_tot_diff = richest_tot - richest_tot_mean
gen log_richest_diff = log_richest - log_richest_mean
graph twoway (lfitci logCost_diff poorest_tot_diff) (scatter logCost_diff poorest_tot_diff, msymbol(o)), xtitle("Demeaned % of Poorest") legend(off) name(res1) nodraw
graph twoway (lfitci logCost_diff log_poorest_diff) (scatter logCost_diff log_poorest_diff, msymbol(o)), xtitle("Demeaned ln(% of Poorest)") legend(off) name(res2) nodraw
graph twoway (lfitci logCost_diff richest_tot_diff) (scatter logCost_diff richest_tot_diff, msymbol(o)), xtitle("Demeaned % of Richest") legend(off) name(res3) nodraw
graph twoway (lfitci logCost_diff log_richest_diff) (scatter logCost_diff log_richest_diff, msymbol(o)),  xtitle("Demeaned ln(% of Richest)") legend(off) name(res4) nodraw
graph combine res1 res2 res3 res4, cols(2) title("Bivariate scatter plots, demeaned at country level") l1title("Demeaned ln(Total Aid Value)")
drop logCost_mean poorest_tot_mean log_poorest_mean richest_tot_mean log_richest_mean logCost_diff poorest_tot_diff richest_tot_diff log_poorest_diff log_richest_diff

//Regressions from Table 3 (main results), on trimmed sample (Table 8)
xtreg prop_totalcost poorest_tot richest_tot capital prop_battles prop_area if numadm1s > 4 & totprojpercountry > 4, robust fe
	outreg2 using MainTable_ROBUST.xls, se nolabel dec(2) coefastr ctitle(Cost) replace
xtreg prop_totalproj poorest_tot richest_tot capital prop_battles prop_area if numadm1s > 4 & totprojpercountry > 4, robust fe
	outreg2 using MainTable_ROBUST.xls, se nolabel dec(2) coefastr ctitle(Proj) append
xtreg logCost log_poorest log_richest capital acled_battles log_area if numadm1s > 4 & totprojpercountry > 4, robust fe
	outreg2 using MainTable_ROBUST.xls, se nolabel dec(2) coefastr ctitle(LogCost) append

//Regressions from Table 3 (main results), but with inequality control (Table 9)
xtreg prop_totalcost poorest_tot richest_tot capital prop_battles prop_area unequal, robust fe
	outreg2 using MainTableUnequal.xls, se nolabel dec(2) coefastr ctitle(Cost) replace
xtreg prop_totalproj poorest_tot richest_tot capital prop_battles prop_area unequal, robust fe
	outreg2 using MainTableUnequal.xls, se nolabel dec(2) coefastr ctitle(Proj) append
xtreg logCost log_poorest log_richest capital acled_battles log_area unequal, robust fe
	outreg2 using MainTableUnequal.xls, se nolabel dec(2) coefastr ctitle(LogCost) append

//Regressions from Table 3 (main results), but with Tobit model (Table 10)
//Tobit models, which takes into consideration truncation of the % DVs at 0 and 1.
//Explaining aid as proportions of cost (tobit)
xttobit prop_totalcost poorest_tot richest_tot capital prop_battles prop_area, ll(0) ul(1) re
	outreg2 using TobitTable.xls, se nolabel dec(2) coefastr ctitle(Cost) replace
//Drop countries that have fewer than 5 ADM1s and fewer than 5 projects
xttobit prop_totalcost poorest_tot richest_tot capital prop_battles prop_area if numadm1s > 4 & totprojpercountry > 4, ll(0) ul(1) re 
	outreg2 using TobitTable.xls, se nolabel dec(2) coefastr ctitle(Small Sample) append
//Explaining aid as proportions of projects (tobit)
xttobit prop_totalproj poorest_tot richest_tot capital prop_battles prop_area, ll(0) ul(1) re
	outreg2 using TobitTable.xls, se nolabel dec(2) coefastr ctitle(Proj) append
//Drop countries that have fewer than 5 ADM1s and fewer than 5 projects
xttobit prop_totalproj poorest_tot richest_tot capital prop_battles prop_area if numadm1s > 4 & totprojpercountry > 4, ll(0) ul(1) re 
	outreg2 using TobitTable.xls, se nolabel dec(2) coefastr ctitle(Small Sample) append

//Do tobit again, but with dummies for FE instead of RE
tobit prop_totalcost poorest_tot richest_tot capital prop_battles prop_area i.adm0_codey, ll(0) ul(1) cluster(adm0_codey)
tobit prop_totalcost poorest_tot richest_tot capital prop_battles prop_area i.adm0_codey if numadm1s > 4 & totprojpercountry > 4, ll(0) ul(1) cluster(adm0_codey)
tobit prop_totalproj poorest_tot richest_tot capital prop_battles prop_area i.adm0_codey, ll(0) ul(1) cluster(adm0_codey)
tobit prop_totalproj poorest_tot richest_tot capital prop_battles prop_area i.adm0_codey if numadm1s > 4 & totprojpercountry > 4, ll(0) ul(1) cluster(adm0_codey)
	
//GLM with logit link, for use with DVs that are bound at zero and one
glm prop_totalproj poorest_tot richest_tot capital prop_battles prop_area i.adm0_codey, link(logit) family(binomial) cluster(adm0_codey) nolog
margins, atmeans at(richest_tot =(0(.1)1) poorest_tot=0) vsquish
marginsplot, recast(line) recastci(rline) legend(off) xlabel(0(.2)1) ylabel(0(0.5)1) ciopts(lpattern(".")) nodraw ytitle("Predicted Share of Projects") title("")
graph copy First, replace 
margins, atmeans at(poorest_tot =(0(.1)1) richest_tot=0) vsquish
marginsplot, recast(line) recastci(rline) legend(off) xlabel(0(.2)1) ylabel(0(0.5)1) ciopts(lpattern(".")) nodraw ytitle("Predicted Share of Projects") title("")
graph copy Second, replace 

glm prop_totalcost poorest_tot richest_tot capital prop_battles prop_area i.adm0_codey, link(logit) family(binomial) cluster(adm0_codey) nolog
margins, atmeans at(richest_tot =(0(.1)1) poorest_tot=0) vsquish
marginsplot, recast(line) recastci(rline) legend(off) xlabel(0(.2)1) ylabel(0(0.5)1) ciopts(lpattern(".")) nodraw ytitle("Predicted Share of Cost") title("")
graph copy Third, replace 
margins, atmeans at(poorest_tot =(0(.1)1) richest_tot=0) vsquish
marginsplot, recast(line) recastci(rline) legend(off) xlabel(0(.2)1) ylabel(0(0.5)1) ciopts(lpattern(".")) nodraw  ytitle("Predicted Share of Cost")  title("")
graph copy Fourth, replace 
graph combine First Second Third Fourth, ycommon title("")

//Ethnic targeting results (Table 11)
//The President's region is not favored, and the same goes for the rich or poor in that region
xtreg prop_totalcost poorest_tot richest_tot presbirth capital prop_battles prop_area, robust fe
	outreg2 using EthnicTable.xls, se nolabel dec(2) coefastr ctitle(Ethnic) replace
xtreg prop_totalcost i.presbirth##c.poorest_tot i.presbirth##c.richest_tot capital prop_battles prop_area, robust fe
	outreg2 using EthnicTable.xls, se nolabel dec(2) coefastr ctitle(Interac) append
xtreg logCost log_poorest log_richest presbirth capital acled_battles log_area, robust fe
	outreg2 using EthnicTable.xls, se nolabel dec(2) coefastr ctitle(LnEthnic) append
xtreg logCost i.presbirth##c.log_poorest i.presbirth##c.log_richest presbirth capital acled_battles log_area, robust fe
	outreg2 using EthnicTable.xls, se nolabel dec(2) coefastr ctitle(LnInterac) append

//Ethnic targeting results also hold for the share of project aid DV (not reported, but discussed in appendix)
xtreg prop_totalproj c.poorest_tot richest_tot presbirth capital prop_battles prop_area, robust fe
xtreg prop_totalproj i.presbirth##c.poorest_tot i.presbirth##c.richest_tot capital prop_battles prop_area, robust fe

//Regressions from Table 3 (main results), but re-weighting regions so that each country has equal weight (Table 12)
xtreg prop_totalcost poorest_tot richest_tot capital prop_battles prop_area [pweight=weight], robust fe
	outreg2 using MainTableWeight.xls, se nolabel dec(2) coefastr ctitle(Cost) replace
xtreg prop_totalproj poorest_tot richest_tot capital prop_battles prop_area [pweight=weight], robust fe
	outreg2 using MainTableWeight.xls, se nolabel dec(2) coefastr ctitle(Proj) append
xtreg logCost log_poorest log_richest capital acled_battles log_area [pweight=weight], robust fe
	outreg2 using MainTableWeight.xls, se nolabel dec(2) coefastr ctitle(LogCost) append

//Note: significant result in re-weighted model 2 goes away if wealth variables are logged
xtreg prop_totalproj log_poorest log_richest capital prop_battles prop_area [pweight=weight], robust fe

//The richest are far more likely to live in capital cities (Table 13)
xtreg richest_tot capital, robust fe
	outreg2 using Capital.xls, se nolabel dec(2) coefastr ctitle(1) replace
xtreg richest_tot capital log_area, robust fe
	outreg2 using Capital.xls, se nolabel dec(2) coefastr ctitle(2) append

//show bivariate effects across wealth groupings, by donor (Figure 6)
foreach var in log_poorest log_poorer log_middle log_richer log_richest {
	quietly xtreg logCostWB `var', robust fe
		estimates store `var'1
	quietly xtreg logCostADB `var', robust fe
		estimates store `var'2
}
coefplot (log_poorest1 \ log_poorer1 \ log_middle1 \ log_richer1 \ log_richest1, label("WB Aid")) (log_poorest2 \ log_poorer2 \ log_middle2 \ log_richer2 \ log_richest2, label("ADB Aid")), drop(_cons) xline(0) title("Results by Donor, logged aid")  msymbol(O)

//favoritism across donors, with controls
//ADB favors capital regions, and thereby the rich. WB favors the rich directly.
xtreg logCostADB log_poorest log_richest acled_battles log_area, robust fe
	outreg2 using ADBWBTable.xls, se nolabel dec(2) coefastr ctitle(ADB NoCap) replace
xtreg logCostADB log_poorest log_richest capital acled_battles log_area, robust fe
	outreg2 using ADBWBTable.xls, se nolabel dec(2) coefastr ctitle(ADB) append
xtreg logCostWB log_poorest log_richest acled_battles log_area, robust fe
	outreg2 using ADBWBTable.xls, se nolabel dec(2) coefastr ctitle(WB NoCap) append
xtreg logCostWB log_poorest log_richest capital acled_battles log_area, robust fe
	outreg2 using ADBWBTable.xls, se nolabel dec(2) coefastr ctitle(WB) append

//------leave-one-out robustness tests of project results------
//explaining proportions of total projects across regions within countries
//sequentiall dropping each country
forvalues i=1/17 {
  quietly xtreg prop_totalproj poorest_tot richest_tot capital prop_battles prop_area if DropVar!=`i', robust fe
  estimates store a`i' 
}
coefplot a1 a2 a3 a4 a5 a6 a7 a8 a9 a10 a11 a12 a13 a14 a15 a16 a17, keep(poorest_tot richest_tot) rename(poorest_tot = "% of Poorest", richest_tot = "% of Richest") xline(0) name(a) legend(off) title("Share of Projects") msymbol(O) nodraw

//explaining proportions of total cost across regions within countries
//sequentiall dropping each country
forvalues i=1/17 {
  quietly xtreg prop_totalcost poorest_tot richest_tot capital prop_battles prop_area if DropVar!=`i', robust fe
    estimates store b`i' 
}
coefplot b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17, keep(poorest_tot richest_tot) rename(poorest_tot = "% of Poorest", richest_tot = "% of Richest") xline(0) name(b) legend(off) title("Share of Value") msymbol(O) nodraw
graph combine b a, cols(2)

//--------------------------------------------------------

//sequentially drop counries, plot poorest and richest

forvalues i=1/17 {
  quietly xtreg logCost log_poorest log_richest presbirth capital acled_battles log_area if DropVar!=`i', robust fe
  estimates store g`i' 
}
coefplot g1 g2 g3 g4 g5 g6 g7 g8 g9 g10 g11 g12 g13 g14 g15 g16 g17, keep(log_poorest log_richest) rename(poorest_tot = "ln(% of Poorest)", richest_tot = "ln(% of Richest)") xline(0) legend(off) title("ln(Value of Projects Per Region)") msymbol(O) 

//--------------------------------------------------------

//countries with a value of 1 in this graph (meaning every region gets aid) will drop from xtlogit
graph hbar (mean) GotAid, over(country)

//binary DV results, note the separation in the logit
xtlogit GotAid log_poorest log_richest, fe
	outreg2 using BinaryDV.xls, se nolabel dec(2) coefastr ctitle(Logit 1) replace
xtlogit GotAid log_poorest log_richest capital acled_battles log_area, fe
	outreg2 using BinaryDV.xls, se nolabel dec(2) coefastr ctitle(Logit 2) append
xtreg GotAid log_poorest log_richest, robust fe
	outreg2 using BinaryDV.xls, se nolabel dec(2) coefastr ctitle(OLS 1) append
xtreg GotAid log_poorest log_richest capital acled_battles log_area, robust fe
	outreg2 using BinaryDV.xls, se nolabel dec(2) coefastr ctitle(OLS 2) append

//Figures of the bivariate relatsionship with binary DV (logit and LPM) (not in appendix)
foreach var in log_poorest log_poorer log_middle log_richer log_richest {
	quietly xtlogit GotAid `var', fe
		estimates store `var'1
	quietly xtreg GotAid `var', robust fe
		estimates store `var'2
}
coefplot (log_poorest1 \ log_poorer1 \ log_middle1 \ log_richer1 \ log_richest1, label("Logit")) (log_poorest2 \ log_poorer2 \ log_middle2 \ log_richer2 \ log_richest2, label("LPM") axis(2)), drop(_cons) xline(0) title("Binary DV, bivariate results") xlabel(-1(.5)1.5) xtitle(Logit coefficient) xtitle(LPM  coefficient, axis(2)) msymbol(O)

//Same result when the aid variables are not logged (also not in appendix)
foreach var in poorest_tot poorer_tot middle_tot richer_tot richest_tot {
	quietly xtlogit GotAid `var', fe
		estimates store `var'1
	quietly xtreg GotAid `var', robust fe
		estimates store `var'2
}
coefplot (poorest_tot1 \ poorer_tot1 \ middle_tot1 \ richer_tot1 \ richest_tot1, label("Logit")) (poorest_tot2 \ poorer_tot2 \ middle_tot2 \ richer_tot2 \ richest_tot2, label("LPM") axis(2)), drop(_cons) xline(0) title("Binary DV, bivariate results") xlabel(-10(5)15) xlabel(-1(.5)1.5, axis(2)) xtitle(Logit coefficient) xtitle(LPM  coefficient, axis(2)) msymbol(O)
